import json
import requests

__version__ = 0.5

def _get_json(date, country, language, timezone): # timezone '-420'(GMT-7 == -7*60)
    # get json from google trends    
    params = {
        'hl': language,
        'tz': timezone,
        'ed': date,
        'geo': country,
        }
    headers = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; rv:78.0) Gecko/20100101 Firefox/78.0"}
    r = requests.get("https://trends.google.com/trends/api/dailytrends", headers=headers, params=params)
    i = r.text.index('{')
    r = r.text[i:]
    r = json.loads(r)    
    return r

def gtrends(date=None, country='US', language='en-US', timezone='-180'): # timezone '-420'(GMT-7 == -7*60)
    # date =  YYYYMMDD, else realtime trends (max 30 days ago).
    j = _get_json(date=date, country=country, language=language, timezone=timezone)
    r = j['default']['trendingSearchesDays'][0]
    data = r['trendingSearches']
    res = []
    for r in data:
        t = r['title']['query']
        res.append(t)  
    return res



from setuptools import setup
from google_trends import __version__

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="google_trends",
    version=__version__,
    author="deedy5",
    description="simple Google Trends API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/deedy5/google_trends",
    license="MIT",
    py_modules=["google_trends"],
    install_requires=["requests>=2.25.0"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",       
    ],
    python_requires=">=3.6",
    zip_safe=False,
)
